@@ -3,7 +3,7 @@ package Mnet;
 # version number used by Makefile.PL
 #   these should be set to "dev", expect when creating a new release
 #   refer to developer build notes in Makefile.PL for more info
-our $VERSION = "5.14";
+our $VERSION = "5.15";
 
 =head1 NAME
 
@@ -76,10 +76,12 @@ Mnet - Testable network automation and reporting
     $log->info("processing device");
 
     # create an expect ssh session to --device
-    #   password_in set to prompt for password if not set via cli option
+    #   log login authentication prompts as info, instead of default debug
+    #   password_in set to prompt for password if --password opt not set
     #   ssh host/key checks can be skipped, refer to Mnet::Expect::Cli
     my $ssh = Mnet::Expect::Cli::Ios->new({
         spawn       => [ "ssh", "$cli->{username}\@$cli->{device}" ],
+        log_login   => "info",
         password    => $cli->password,
         password_in => 1,
     });
