@@ -100,7 +100,6 @@ INIT {
             use --batch-min to set number of concurrent batch processes
             refer to perldoc Mnet::Batch for more information
         ',
-        norecord    => 1,
     }) if $INC{"Mnet/Opts/Cli.pm"};
     Mnet::Opts::Cli::define({
         getopt      => 'batch-idle=i',
@@ -115,20 +114,18 @@ INIT {
             refer to --help batch and --help batch-min for more info
             refer also to perldoc Mnet::Batch for more information
         ',
-        norecord    => 1,
     }) if $INC{"Mnet/Opts/Cli.pm"};;
     Mnet::Opts::Cli::define({
         getopt      => 'batch-min=i',
         default     => $def->{batch_min},
         help_hide   => 1,
-        help_tip    => 'set number of concurrent batch processes',
+        help_tip    => 'set number of concurrent processes',
         help_text   => '
             default is to allow a minimum of 1 batch child processes
             this may be increased on systems that support --batch-idle
             refer to --help batch and --help --batch-idle for more infor
             refer also to perldoc Mnet::Batch for more information
         ',
-        norecord    => 1,
     }) if $INC{"Mnet/Opts/Cli.pm"};;
 }
 
